CsvParser class
Parses UTF-8 CSV bytes into an ExcelWorkbook.
Constructors
- CsvParser()
-
Creates a CSV parser.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseBytes(
Uint8List bytes) → ExcelWorkbook -
Parses
bytesand returns a single-sheet workbook. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited